@@ -16,39 +16,34 @@
 
 namespace Views {
 
-  class DataEntry : public Lum::Model::ListTable::Entry
+  class DataEntryDataProvider : public DataEntryModel::DataProvider
   {
   public:
-    ::Base::DataPtr data;
-
-  public:
-    DataEntry(Lum::Model::ListTable* table, ::Base::DataPtr data)
-    : Lum::Model::ListTable::Entry(table),data(data)
-    {
-      // no code
-    }
-
-    std::wstring GetString(size_t column) const
+    std::wstring GetString(const DataEntryModel::Iterator& iter, size_t column) const
     {
       switch (column) {
       case 1:
-        return data->GetType()->GetName();
+        return (*iter)->data->GetType()->GetName();
       case 2:
-        return data->GetDisplayText();
+        return (*iter)->data->GetDisplayText();
       default:
         return L"";
       }
     }
+  };
 
-    bool IsGreater(const Lum::Model::ListTable::Entry* other, size_t column) const
+  class DataEntryComparator : public DataEntryModel::Comparator
+  {
+  public:
+    bool operator()(const DataEntryModel::ElementType& a,
+                    const DataEntryModel::ElementType& b,
+                    size_t column, bool down) const
     {
-      ::Base::DataPtr tmp=dynamic_cast<const DataEntry*>(other)->data;
-
-      if (data->GetType()->GetName()==tmp->GetType()->GetName()) {
-        return data->GetDisplayText()>tmp->GetDisplayText();
+      if (a->data->GetType()->GetName()==b->data->GetType()->GetName()) {
+        return a->data->GetDisplayText()<b->data->GetDisplayText();
       }
       else {
-        return data->GetType()->GetName()>tmp->GetType()->GetName();
+        return a->data->GetType()->GetName()<b->data->GetType()->GetName();
       }
     }
   };
@@ -57,7 +52,8 @@ namespace Views {
   : View(L"Search"),
     viewAction(new Lum::Model::Action),
     searchAction(new Lum::Model::Action),
-    model(new Lum::Model::ListTable()),
+    model(new DataEntryModel(new DataEntryDataProvider(),
+                             new DataEntryComparator())),
     searchValue(new Lum::Model::String()),
     table(NULL),top(NULL)
   {
@@ -85,7 +81,7 @@ namespace Views {
       while (iter!=database->database.end()) {
         for (size_t x=0; x<=(*iter)->GetType()->GetMaxAttribute(); x++) {
           if ((*iter)->GetAttribute(x).find(searchValue->Get())!=std::string::npos) {
-            model->Append(new DataEntry(model,*iter));
+            model->Append(new DataEntry(*iter));
             break;
           }
         }
